@@ -1,6 +1,6 @@
 hcaScores <-
 function(spectra, pca, title = "no title provided", scores = c(1:5),
-method = "complete", use.sym = FALSE, ...) {
+c.method = "complete", d.method = "euclidean", use.sym = FALSE, ...) {
 
 # Function to carry out HCA on PCA scores
 # Part of the ChemoSpec package
@@ -13,12 +13,12 @@ method = "complete", use.sym = FALSE, ...) {
 	chkSpectra(spectra)
 
 	if (use.sym) spectra$names <- paste(spectra$alt.sym, spectra$names, sep = " ")
-	distance <- dist(as.data.frame(pca$x[,scores], row.names = spectra$names))
+	distance <- rowDist(as.data.frame(pca$x[,scores], row.names = spectra$names), method = d.method)
 
 	title <- paste(title, ": HCA Analysis of PC Scores", sep = "")
-	sub.title <- paste("Clustering method: ", method, sep = "")
+	sub.title <- paste("clustering method: ", c.method, "      distance method: ", d.method, sep = "")
 
 	plotHCA(spectra = spectra, distance = distance, title = title, sub.title = sub.title,
-		method = method, use.sym = use.sym)
+		method = c.method, use.sym = use.sym)
 	}
 
