@@ -1,5 +1,5 @@
 normSpectra <-
-function(spectra) {
+function(spectra, method = "ti") {
 	
 # Function to Normalize the data in a Spectra object
 # Part of the ChemoSpec package
@@ -10,10 +10,13 @@ function(spectra) {
 
 # normalize by a row by the sum of its entries:
 
-	for (n in 1:length(spectra$names)) {
-		S <- sum(spectra$data[n,])
-		spectra$data[n,] <- spectra$data[n,]/S
+	if (method == "ti") {
+		for (n in 1:length(spectra$names)) {
+			S <- sum(spectra$data[n,])
+			spectra$data[n,] <- spectra$data[n,]/S
+			}
 		}
+
 	chkSpectra(spectra)
 	spectra
 	}
